# pymasep - Python Multiagent system engine plateform

Multiagent system library in python.

This preliminary version aims to reserve the name on pypi. 
My old name (pymas) was already taken and I realized it during the first upload...

Real version (0.1) will be uploaded soon when the old project will be renamed

